import { LogInput } from './LogInput';
import { LogLevels } from './logLevels';
import { LogOutput } from './LogOutput';
/**
 * Provides methods for writing logs to in different log-levels. Logs are written in JSON format to stdout using console.log().
 */
declare class Logger {
    /**
     * This governs which logs will be written. If log level is
     * INFO all logs with INFO and above will be written. So: INFO
     * WARN and ERROR.
     */
    level: LogLevels;
    /**
     * Sets a reference to the AWS lambda context object and will enrich the logs with context meta data to make it easier to track.
     */
    context: AWSLambda.Context | undefined;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    debug(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    info(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    warn(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {
     * message: 'This is my message',
     * context: AwsLambdaContext,
     * xRequestId: 'id-from-external-system',
     * something: 'my property',
     * somethingElse: 'another extra property' }
     */
    error(logInput: LogInput): void;
    private createLogJson;
    /**
     * If we find a property of type Error we cannot stringify it directly because it
     * will just be outputted as "{}", instead if we find an instanceof Error we add
     * the stack to a stack property.
     */
    private preProcessErrorProperties;
}
declare const log: Logger;
export { log, LogLevels, LogInput, LogOutput };
